.. _utilipy-utils-exceptions:

***************************************
Exceptions (`utilipy.utils.exceptions`)
***************************************

.. currentmodule:: utilipy.utils.exceptions


Reference/API
=============

.. automodapi:: utilipy.utils.exceptions
